==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24SplitPaneDividerBorder.h <==
// class javax.swing.plaf.basic.BasicBorders$SplitPaneDividerBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 394b2507fa72237c javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JSplitPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_javax_swing_JSplitPane$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$getSplitPane$3fd6d7ec39a30cc9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$getSplitPane$3fd6d7ec39a30cc9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_javax_swing_JSplitPane$object	*(*getSplitPane$3fd6d7ec39a30cc9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs {
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*shadow;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24SplitPaneDividerBorder.h <==
// class javax.swing.plaf.basic.BasicBorders$SplitPaneDividerBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 394b2507fa72237c javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JSplitPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JSplitPane$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$getSplitPane$3fd6d7ec39a30cc9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$getSplitPane$3fd6d7ec39a30cc9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_JSplitPane$object	*(*getSplitPane$3fd6d7ec39a30cc9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs {
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*shadow;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneDividerBorder_H_ */
